package com.ruoyi.invest.mapper;

import java.util.List;
import com.ruoyi.invest.domain.InstallmentHistoryDetail;
import com.ruoyi.invest.domain.dto.InstallmentHistoryDetailDto;
import com.ruoyi.invest.domain.vo.InstallmentHistoryDetailVo;

/**
 * 分期历史明细Mapper接口
 *
 * @author tianyongbao
 * @date 2024-03-23
 */
public interface InstallmentHistoryDetailMapper
{
    /**
     * 查询分期历史明细
     *
     * @param id 分期历史明细主键
     * @return 分期历史明细
     */
    public InstallmentHistoryDetailVo selectInstallmentHistoryDetailById(Long id);

    /**
     * 查询分期历史明细列表
     *
     * @param installmentHistoryDetailDto 分期历史明细
     * @return 分期历史明细集合
     */
    public List<InstallmentHistoryDetailVo> selectInstallmentHistoryDetailList(InstallmentHistoryDetailDto installmentHistoryDetailDto);

    /**
     * 新增分期历史明细
     *
     * @param installmentHistoryDetail 分期历史明细
     * @return 结果
     */
    public int insertInstallmentHistoryDetail(InstallmentHistoryDetail installmentHistoryDetail);

    /**
     * 修改分期历史明细
     *
     * @param installmentHistoryDetail 分期历史明细
     * @return 结果
     */
    public int updateInstallmentHistoryDetail(InstallmentHistoryDetail installmentHistoryDetail);

    /**
     * 删除分期历史明细
     *
     * @param id 分期历史明细主键
     * @return 结果
     */
    public int deleteInstallmentHistoryDetailById(Long id);

    /**
     * 批量删除分期历史明细
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInstallmentHistoryDetailByIds(Long[] ids);

    /**
     * 逻辑删除分期历史明细
     *
     * @param id 分期历史明细主键
     * @return 结果
     */
    public int removeInstallmentHistoryDetailById(Long id);

    /**
     * 批量逻辑删除分期历史明细
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int removeInstallmentHistoryDetailByIds(Long[] ids);
}
